summaryrefslogtreecommitdiffstats
path: root/src/Blocks/BlockSapling.h
diff options
context:
space:
mode:
authorTiger Wang <ziwei.tiger@hotmail.co.uk>2014-07-22 21:10:02 +0200
committerTiger Wang <ziwei.tiger@hotmail.co.uk>2014-07-22 21:10:02 +0200
commitb5e5586ab04b4cb7d630bc8a4999e23eba71a6e5 (patch)
tree089b3be905aa030367925762c58bd30b08f5f3f6 /src/Blocks/BlockSapling.h
parentUpdated prefabs to current Gallery content. (diff)
parentMerge remote-tracking branch 'origin/master' into saplingsandleaves (diff)
downloadcuberite-b5e5586ab04b4cb7d630bc8a4999e23eba71a6e5.tar
cuberite-b5e5586ab04b4cb7d630bc8a4999e23eba71a6e5.tar.gz
cuberite-b5e5586ab04b4cb7d630bc8a4999e23eba71a6e5.tar.bz2
cuberite-b5e5586ab04b4cb7d630bc8a4999e23eba71a6e5.tar.lz
cuberite-b5e5586ab04b4cb7d630bc8a4999e23eba71a6e5.tar.xz
cuberite-b5e5586ab04b4cb7d630bc8a4999e23eba71a6e5.tar.zst
cuberite-b5e5586ab04b4cb7d630bc8a4999e23eba71a6e5.zip
Diffstat (limited to 'src/Blocks/BlockSapling.h')
-rw-r--r--src/Blocks/BlockSapling.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/Blocks/BlockSapling.h b/src/Blocks/BlockSapling.h
index 3f443b734..e965809a3 100644
--- a/src/Blocks/BlockSapling.h
+++ b/src/Blocks/BlockSapling.h
@@ -20,8 +20,8 @@ public:
virtual void ConvertToPickups(cItems & a_Pickups, NIBBLETYPE a_BlockMeta) override
{
- // Only the first 2 bits contain the display information, the others are for growing
- a_Pickups.push_back(cItem(E_BLOCK_SAPLING, 1, a_BlockMeta & 0x7));
+ // Only the first 5 bits contain the display information, 8th bit for growth indicator (but we use 0x07 for forward compatibility)
+ a_Pickups.push_back(cItem(E_BLOCK_SAPLING, 1, a_BlockMeta & 0x07));
}